@@ -34,5 +34,6 @@ def test_function_checker():
         'biszx-search-func-name': 1,
         'biszx-compute-func-name': 2,
         'biszx-onchange-func-name': 1,
-        'biszx-constrains-func-name': 1
+        'biszx-constrains-func-name': 1,
+        'biszx-inverse-func-name': 1,
     }
